@@ -121,9 +121,7 @@ class JobStatusFormatter:
         resources = Table(box=None, show_header=False, show_edge=False)
         resources.add_column()
         resources.add_column(style="bold", justify="right")
-        resources.add_row(
-            "Memory", format_size(job_status.container.resources.memory_mb * 1024**2)
-        )
+        resources.add_row("Memory", format_size(job_status.container.resources.memory))
         resources.add_row("CPU", f"{job_status.container.resources.cpu:0.1f}")
         if job_status.container.resources.gpu:
             resources.add_row(
