@@ -3,7 +3,8 @@ import operator
 from typing import Sequence
 
 from rich import box
-from rich.console import RenderableType, RenderGroup
+from rich.console import Group as RichGroup
+from rich.console import RenderableType
 from rich.table import Table
 from rich.text import Text
 
@@ -21,7 +22,7 @@ class BaseSecretsFormatter:
 
 class SimpleSecretsFormatter(BaseSecretsFormatter):
     def __call__(self, secrets: Sequence[Secret]) -> RenderableType:
-        return RenderGroup(*(Text(secret.key) for secret in secrets))
+        return RichGroup(*(Text(secret.key) for secret in secrets))
 
 
 class SecretsFormatter(BaseSecretsFormatter):
