@@ -116,6 +116,7 @@ class Helper:
         self._tmpstorage = URL(f"storage:{self.tmpstoragename}")
         self._closed = False
         self._executed_jobs: List[str] = []
+        self.DEFAULT_PRESET = os.environ.get("E2E_PRESET", "cpu-small")
 
     def close(self) -> None:
         if not self._closed:
@@ -136,6 +137,19 @@ class Helper:
         config = self.get_config()
         return config.cluster_name
 
+    @cached_property
+    def org_name(self) -> Optional[str]:
+        config = self.get_config()
+        return config.org_name
+
+    @cached_property
+    def cluster_uri_base(self) -> str:
+        result = self.cluster_name
+        if self.org_name is not None:
+            result += "/" + self.org_name
+        result += "/" + self.username
+        return result
+
     @cached_property
     def token(self) -> str:
         config = self.get_config()
@@ -157,7 +171,7 @@ class Helper:
 
     def make_uri(self, path: str, *, fromhome: bool = False) -> URL:
         if fromhome:
-            return URL(f"storage://{self.cluster_name}/{self.username}/{path}")
+            return URL(f"storage://{self.cluster_uri_base}/{path}")
         else:
             return self.tmpstorage / path
 
@@ -397,12 +411,15 @@ class Helper:
                 async for chunk in it:
                     if not chunk:
                         break
-                    chunks.append(chunk.decode())
-                    if re.search(expected, "".join(chunks), flags):
+                    chunks.append(chunk)
+                    if re.search(expected, b"".join(chunks).decode(), flags):
                         return
                     if time() - started_at > JOB_OUTPUT_TIMEOUT:
                         break
 
+        print(f"Output of job {job_id}:")
+        for chunk in chunks:
+            print(f"  {chunk!r}")
         raise AssertionError(
             f"Output of job {job_id} does not satisfy to expected regexp: {expected}"
         )
@@ -489,6 +506,25 @@ class Helper:
             print(f"neuro stderr: {err}")
         return SysCap(out, err)
 
+    def run_cli_run_job(
+        self,
+        arguments: List[Any],
+        *,
+        verbosity: int = 0,
+        network_timeout: float = NETWORK_TIMEOUT,
+        input: Optional[str] = None,
+        timeout: float = 300,
+    ) -> SysCap:
+        if self.DEFAULT_PRESET:
+            arguments = ["-s", self.DEFAULT_PRESET, *arguments]
+        return self.run_cli(
+            ["job", "run", *arguments],
+            verbosity=verbosity,
+            network_timeout=network_timeout,
+            input=input,
+            timeout=timeout,
+        )
+
     def find_job_id(self, arg: str) -> Optional[str]:
         match = JOB_ID_PATTERN.search(arg)
         return match.group(1) if match else None
@@ -563,7 +599,7 @@ class Helper:
             env = {}
         async with api_get(timeout=CLIENT_TIMEOUT, path=self._nmrc_path) as client:
             preset = client.presets["cpu-micro"]
-            resources = Resources(memory_mb=preset.memory_mb, cpu=preset.cpu)
+            resources = Resources(memory=preset.memory, cpu=preset.cpu)
             container = Container(
                 image=client.parse.remote_image(image),
                 command=command,
@@ -793,6 +829,7 @@ def _get_nmrc_path(tmp_path: Any, require_admin: bool) -> Optional[Path]:
 @pytest.fixture
 def helper(tmp_path: Path, nmrc_path: Path) -> Iterator[Helper]:
     ret = Helper(nmrc_path=nmrc_path, tmp_path=tmp_path)
+    ret.cluster_uri_base  # get and cache properties outside of the event loop
     yield ret
     with suppress(Exception):
         # ignore exceptions in helper closing
@@ -909,8 +946,9 @@ def secret_job(helper: Helper) -> Callable[[bool, bool, Optional[str]], Dict[str
                 if http_auth:
                     description += " with authentication"
         args += ["-d", description]
-        capture = helper.run_cli(
-            ["-q", "job", "run", "--detach", *args, NGINX_IMAGE_NAME, "--", command]
+        capture = helper.run_cli_run_job(
+            ["--detach", *args, NGINX_IMAGE_NAME, "--", command],
+            verbosity=-1,
         )
         http_job_id = capture.out
         status: JobDescription = helper.job_info(http_job_id, wait_start=True)
