@@ -65,12 +65,12 @@ def test_images_complete_lifecycle(
     # stderr has "Used image ..." lines
     # assert not captured.err
 
-    image_full_str = f"image://{helper.cluster_name}/{helper.username}/{image}"
+    image_full_str = f"image://{helper.cluster_uri_base}/{image}"
     assert captured.out.endswith(image_full_str)
     image_url = URL(image_full_str)
 
     # Check if image available on registry
-    image_full_str = f"image://{helper.cluster_name}/{helper.username}/{image}"
+    image_full_str = f"image://{helper.cluster_uri_base}/{image}"
     image_short_str = f"image:{image}"
     assert captured.out.endswith(image_full_str)
 
@@ -112,7 +112,7 @@ def test_images_complete_lifecycle(
     assert image in local_images
 
     # Execute image and check result
-    captured = helper.run_cli(["-q", "run", "--no-wait-start", str(image_url)])
+    captured = helper.run_cli_run_job(["--no-wait-start", str(image_url)], verbosity=-1)
     assert not captured.err
     job_id = captured.out
     assert job_id.startswith("job-")
@@ -120,13 +120,15 @@ def test_images_complete_lifecycle(
 
     helper.check_job_output(job_id, re.escape(tag))
 
+    helper.run_cli(["image", "rm", image_full_str_no_tag])
+
 
 @pytest.mark.e2e
 def test_image_tags(helper: Helper, image: str, tag: str) -> None:
     # push image
     captured = helper.run_cli(["image", "push", image])
 
-    image_full_str = f"image://{helper.cluster_name}/{helper.username}/{image}"
+    image_full_str = f"image://{helper.cluster_uri_base}/{image}"
     assert captured.out.endswith(image_full_str)
 
     image_full_str_no_tag = image_full_str.replace(f":{tag}", "")
@@ -163,6 +165,8 @@ def test_image_tags(helper: Helper, image: str, tag: str) -> None:
     assertion_msg = f"Command {cmd} should fail: {result.stdout!r} {result.stderr!r}"
     assert result.returncode, assertion_msg
 
+    helper.run_cli(["image", "rm", image_full_str_no_tag])
+
 
 @pytest.mark.e2e
 async def test_images_delete(
@@ -207,11 +211,8 @@ async def test_images_push_with_specified_name(
     captured = helper.run_cli(["image", "push", image, f"image:{pushed_no_tag}:{tag}"])
     # stderr has "Used image ..." lines
     # assert not captured.err
+    image_pushed_full_str = f"image://{helper.cluster_uri_base}/{pushed_no_tag}:{tag}"
     async with helper.client() as client:
-        image_pushed_full_str = (
-            f"image://{client.config.cluster_name}/"
-            f"{client.config.username}/{pushed_no_tag}:{tag}"
-        )
         assert captured.out.endswith(image_pushed_full_str)
 
     # Check if image available on registry
@@ -244,6 +245,8 @@ async def test_images_push_with_specified_name(
     # delete locally
     await docker.images.delete(pulled, force=True)
 
+    helper.run_cli(["image", "rm", f"image:{pushed_no_tag}"])
+
 
 @pytest.mark.e2e
 def test_docker_helper(
@@ -251,22 +254,27 @@ def test_docker_helper(
 ) -> None:
     monkeypatch.setenv(CONFIG_ENV_NAME, str(nmrc_path or DEFAULT_CONFIG_PATH))
     helper.run_cli(["config", "docker"])
-    registry = helper.registry_url.host
-    username = helper.username
-    full_tag = f"{registry}/{username}/{image}"
+    full_tag = helper.registry_url.host
+    assert full_tag
+    if helper.org_name:
+        full_tag += f"/{helper.org_name}"
+    full_tag += f"/{helper.username}/{image}"
     tag_cmd = f"docker tag {image} {full_tag}"
     result = subprocess.run(tag_cmd, capture_output=True, shell=True)
     assert (
-        not result.returncode
+        result.returncode == 0
     ), f"Command {tag_cmd} failed: {result.stdout!r} {result.stderr!r} "
     push_cmd = f"docker push {full_tag}"
     result = subprocess.run(push_cmd, capture_output=True, shell=True)
     assert (
-        not result.returncode
+        result.returncode == 0
     ), f"Command {push_cmd} failed: {result.stdout!r} {result.stderr!r} "
     # Run image and check output
-    image_url = f"image://{helper.cluster_name}/{username}/{image}"
+    image_url = f"image://{helper.cluster_uri_base}/{image}"
     job_id = helper.run_job_and_wait_state(
         image_url, "", wait_state=JobStatus.SUCCEEDED, stop_state=JobStatus.FAILED
     )
     helper.check_job_output(job_id, re.escape(tag))
+
+    image_full_str_no_tag = image_url.replace(f":{tag}", "")
+    helper.run_cli(["image", "rm", image_full_str_no_tag])
