@@ -513,10 +513,7 @@ def test_e2e_glob(tmp_path: Path, helper: Helper) -> None:
 
     # Test subcommand "glob"
     captured = helper.run_cli(["storage", "glob", helper.tmpstorage / "**"])
-    prefix = (
-        f"storage://{helper.cluster_name}/{helper.username}/"
-        f"{helper.tmpstorage.path}"
-    )
+    prefix = f"storage://{helper.cluster_uri_base}/{helper.tmpstorage.path}"
     assert sorted(captured.out.splitlines()) == [
         prefix.rstrip("/"),
         prefix + "/folder",
@@ -694,7 +691,6 @@ def test_tree(helper: Helper, data: _Data, tmp_path: Path) -> None:
 @pytest.mark.skipif(
     sys.platform == "win32", reason="Autocompletion is not supported on Windows"
 )
-@pytest.mark.xfail(reason="autocomplete is not working")
 @pytest.mark.e2e
 def test_storage_autocomplete_remote(helper: Helper, tmp_path: Path) -> None:
     folder = tmp_path / "folder"
@@ -735,7 +731,6 @@ def test_storage_autocomplete_remote(helper: Helper, tmp_path: Path) -> None:
 @pytest.mark.skipif(
     sys.platform == "win32", reason="Autocompletion is not supported on Windows"
 )
-@pytest.mark.xfail(reason="autocomplete is not working")
 @pytest.mark.e2e
 def test_storage_autocomplete_local(helper: Helper, tmp_path: Path) -> None:
     folder = tmp_path / "folder"
